@@ -11,7 +11,6 @@ accepted by the membership of KDE e.V. (or its successor approved
 by the membership of KDE e.V.), which shall act as a proxy
 defined in Section 14 of version 3 of the license.
 
-
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -25,18 +24,18 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #ifndef BEHAVIORCONFIG_H
 #define BEHAVIORCONFIG_H
 
-#include <kcmodule.h>
+#include <KCModule>
 
 class BehaviorConfig : public KCModule
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     BehaviorConfig(QWidget *parent, const QVariantList &args) ;
     ~BehaviorConfig();
 
-    virtual void save();
-    virtual void load();
+    virtual void save() override;
+    virtual void load() override;
 
 private:
     class Private;
@@ -44,4 +43,3 @@ private:
 };
 
 #endif
-// vim: set noet ts=4 sts=4 sw=4:
