@@ -33,7 +33,7 @@
 static const char description[] =
     I18N_NOOP("KDE Micro-Blogging Client.");
 
-static const char version[] = "1.6.0";
+static const char version[] = "1.7.0";
 
 int main(int argc, char **argv)
 {
@@ -43,17 +43,18 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("choqok");
     KAboutData about(QLatin1String("choqok"), QLatin1String("Choqok"), QLatin1String(version), i18n(description),
-                     KAboutLicense::GPL_V3, i18n("(C) 2008-2010 Mehrdad Momeny\n(C) 2011-2015 Choqok Developers"),
-                     QString(), QLatin1String("http://choqok.gnufolks.org/"));
+                     KAboutLicense::GPL_V3, i18n("(C) 2008-2010 Mehrdad Momeny\n(C) 2011-2019 Choqok Developers"),
+                     QString(), QLatin1String("https://choqok.kde.org/"));
 
     about.setOrganizationDomain("kde.org");
+    about.setDesktopFileName(QStringLiteral("org.kde.choqok"));
 
     about.addAuthor(i18n("Mehrdad Momeny"), i18n("Author, Developer and Maintainer"),
                     QLatin1String("mehrdad.momeny@gmail.com"), QLatin1String("http://momeny.wordpress.com"));
+    about.addAuthor(i18n("Andrea Scarpino"), i18n("Developer and Maintainer"),
+                    QLatin1String("scarpino@kde.org"), QLatin1String("https://scarpino.dev"));
     about.addAuthor(i18n("Andrey Esin"), i18n("Developer"),
                     QLatin1String("gmlastik@gmail.com"), QLatin1String("https://twitter.com/la_stik"));
-    about.addAuthor(i18n("Andrea Scarpino"), i18n("Developer"),
-                    QLatin1String("scarpino@kde.org"), QLatin1String("http://www.andreascarpino.it"));
 
     about.addCredit(i18n("Roozbeh Shafiee"), i18n("Artworks"), QLatin1String("roozbeh@roozbehonline.com"));
     about.addCredit(i18n("Shahrzad Shojaei"), i18n("Artworks"), QLatin1String("shahrzadesign@gmail.com"));
