@@ -47,11 +47,11 @@ class MediaManager::Private
 {
 public:
     Private()
-        : emoticons(KEmoticons().theme()), cache(QLatin1String("choqok-userimages"), 30000000), uploader(0)
+        : emoticons(KEmoticons().theme()), cache(QLatin1String("choqok-userimages"), 30000000), uploader(nullptr)
     {}
     KEmoticonsTheme emoticons;
     KImageCache cache;
-    QHash<KJob *, QString> queue;
+    QHash<KJob *, QUrl> queue;
     QPixmap defaultImage;
     Uploader *uploader;
 };
@@ -88,18 +88,17 @@ QString MediaManager::parseEmoticons(const QString &text)
     return d->emoticons.parseEmoticons(text, KEmoticonsTheme::DefaultParse, QStringList() << QLatin1String("(e)"));
 }
 
-QPixmap MediaManager::fetchImage(const QString &remoteUrl, ReturnMode mode /*= Sync*/)
+QPixmap MediaManager::fetchImage(const QUrl &remoteUrl, ReturnMode mode /*= Sync*/)
 {
     QPixmap p;
-    if (d->cache.findPixmap(remoteUrl, &p)) {
+    if (d->cache.findPixmap(remoteUrl.toDisplayString(), &p)) {
         Q_EMIT imageFetched(remoteUrl, p);
     } else if (mode == Async) {
         if (d->queue.values().contains(remoteUrl)) {
             ///The file is on the way, wait to download complete.
             return p;
         }
-        QUrl srcUrl(remoteUrl);
-        KIO::StoredTransferJob *job = KIO::storedGet(srcUrl, KIO::NoReload, KIO::HideProgressInfo) ;
+        KIO::StoredTransferJob *job = KIO::storedGet(remoteUrl, KIO::NoReload, KIO::HideProgressInfo) ;
         if (!job) {
             qCCritical(CHOQOK) << "Cannot create a FileCopyJob!";
             QString errMsg = i18n("Cannot create a KDE Job. Please check your installation.");
@@ -107,7 +106,7 @@ QPixmap MediaManager::fetchImage(const QString &remoteUrl, ReturnMode mode /*= S
             return p;
         }
         d->queue.insert(job, remoteUrl);
-        connect(job, SIGNAL(result(KJob*)), this, SLOT(slotImageFetched(KJob*)));
+        connect(job, &KIO::StoredTransferJob::result, this, &MediaManager::slotImageFetched);
         job->start();
     }
     return p;
@@ -116,18 +115,23 @@ QPixmap MediaManager::fetchImage(const QString &remoteUrl, ReturnMode mode /*= S
 void MediaManager::slotImageFetched(KJob *job)
 {
     KIO::StoredTransferJob *baseJob = qobject_cast<KIO::StoredTransferJob *>(job);
-    QString remote = d->queue.value(job);
+    QUrl remote = d->queue.value(job);
     d->queue.remove(job);
-    if (job->error()) {
+
+    int responseCode = 0;
+    if (baseJob->metaData().contains(QStringLiteral("responsecode"))) {
+        responseCode = baseJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+    }
+
+    if (job->error() || (responseCode > 399 && responseCode < 600)) {
         qCCritical(CHOQOK) << "Job error:" << job->error() << "\t" << job->errorString();
-        QString errMsg = i18n("Cannot download image from %1.",
-                              job->errorString());
+        qCCritical(CHOQOK) << "HTTP response code" << responseCode;
+        QString errMsg = i18n("Cannot download image from %1.", job->errorString());
         Q_EMIT fetchError(remote, errMsg);
     } else {
         QPixmap p;
-        if (!baseJob->data().startsWith(QByteArray("<?xml version=\"")) &&
-                p.loadFromData(baseJob->data())) {
-            d->cache.insertPixmap(remote, p);
+        if (p.loadFromData(baseJob->data())) {
+            d->cache.insertPixmap(remote.toDisplayString(), p);
             Q_EMIT imageFetched(remote, p);
         } else {
             qCCritical(CHOQOK) << "Cannot parse reply from " << baseJob->url().toDisplayString();
@@ -191,10 +195,8 @@ void MediaManager::uploadMedium(const QUrl &localUrl, const QString &pluginId)
         KMessageBox::error(UI::Global::mainWindow(), i18n("Uploading medium failed: cannot read the medium file."));
         return;
     }
-    connect(d->uploader, SIGNAL(mediumUploaded(QUrl,QString)),
-            this, SIGNAL(mediumUploaded(QUrl,QString)));
-    connect(d->uploader, SIGNAL(uploadingFailed(QUrl,QString)),
-            this, SIGNAL(mediumUploadFailed(QUrl,QString)));
+    connect(d->uploader, &Uploader::mediumUploaded, this, &MediaManager::mediumUploaded);
+    connect(d->uploader, &Uploader::uploadingFailed, this, &MediaManager::mediumUploadFailed);
     const QMimeDatabase db;
     d->uploader->upload(localUrl, picData, db.mimeTypeForUrl(localUrl).name().toLocal8Bit());
 }
