@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -22,21 +21,20 @@
 */
 
 #include "shortener.h"
-#include <kdemacros.h>
 
-namespace Choqok{
+namespace Choqok
+{
 
-Shortener::Shortener( const KComponentData &instance, QObject *parent )
-    : Plugin(instance, parent)
+Shortener::Shortener(const QString &componentName, QObject *parent)
+    : Plugin(componentName, parent)
 {
 }
 
 Shortener::~Shortener()
 {}
 
-QString Shortener::shorten( const QString &url )
+QString Shortener::shorten(const QString &url)
 {
     return url;
 }
 }
-#include "shortener.moc"
