@@ -51,8 +51,13 @@ class PostWidget::Private
 {
 public:
     Private(Account *account, Choqok::Post *post)
-        : mCurrentPost(post), mCurrentAccount(account), dir(QLatin1String("ltr")), timeline(0)
+        : mCurrentPost(post), mCurrentAccount(account), dir(QLatin1String("ltr")), timeline(nullptr)
     {
+        mCurrentPost->owners++;
+
+        if (!mCurrentPost->media.isEmpty()) {
+            imageUrl = mCurrentPost->media;
+        }
     }
     QGridLayout *buttonsLayout;
     QMap<QString, QPushButton *> mUiButtons; //<Object name, Button>
@@ -66,7 +71,7 @@ public:
     QString mContent;
     QString mProfileImage;
     QString mImage;
-    QString imageUrl;
+    QUrl imageUrl;
     QString dir;
     QPixmap originalImage;
     QString extraContents;
@@ -107,16 +112,11 @@ PostWidget::PostWidget(Account *account, Choqok::Post *post, QWidget *parent/* =
         d->mCurrentPost->isRead = true;
     }
     d->mTimer.start(_MINUTE);
-    connect(&d->mTimer, SIGNAL(timeout()), this, SLOT(updateUi()));
-    connect(_mainWidget, SIGNAL(clicked(QMouseEvent*)), SLOT(mousePressEvent(QMouseEvent*)));
-    connect(_mainWidget, SIGNAL(anchorClicked(QUrl)), this, SLOT(checkAnchor(QUrl)));
+    connect(&d->mTimer, &QTimer::timeout, this, &PostWidget::updateUi);
+    connect(_mainWidget, &TextBrowser::clicked, this, &PostWidget::mousePressEvent);
+    connect(_mainWidget, &TextBrowser::anchorClicked, this, &PostWidget::checkAnchor);
 
     d->timeline = qobject_cast<TimelineWidget *>(parent);
-    d->mCurrentPost->owners++;
-
-    if (!d->mCurrentPost->media.isEmpty()) {
-        d->imageUrl = d->mCurrentPost->media;
-    }
 
     setHeight();
 }
@@ -150,28 +150,31 @@ Account *PostWidget::currentAccount()
 
 QString PostWidget::generateSign()
 {
-    QString ss = QString(QLatin1String("<b>%1 - </b>")).arg(getUsernameHyperlink(d->mCurrentPost->author.userName, d->mCurrentPost->author.description));
+    QString ss = QStringLiteral("<b>%1 - </b>").arg(getUsernameHyperlink(d->mCurrentPost->author));
 
+    QDateTime time;
     if (d->mCurrentPost->repeatedDateTime.isNull()) {
-        ss += QLatin1String("<a href=\"") + d->mCurrentPost->link +
-            QLatin1String("\" title=\"") + d->mCurrentPost->creationDateTime.toString(Qt::DefaultLocaleLongDate) + QLatin1String("\">%1</a>");
+        time = d->mCurrentPost->creationDateTime;
     } else {
-        ss += QLatin1String("<a href=\"") + d->mCurrentPost->link +
-            QLatin1String("\" title=\"") + d->mCurrentPost->repeatedDateTime.toString(Qt::DefaultLocaleLongDate) + QLatin1String("\">%1</a>");
+        time = d->mCurrentPost->repeatedDateTime;
     }
 
-    if (!d->mCurrentPost->source.isNull()) {
+    ss += QStringLiteral("<a href=\"%1\" title=\"%2\">%3</a>").arg(d->mCurrentPost->link.toDisplayString())
+            .arg(time.toString(Qt::DefaultLocaleLongDate)).arg(formatDateTime(time));
+
+    if (!d->mCurrentPost->source.isEmpty()) {
         ss += QLatin1String(" - ") + d->mCurrentPost->source;
     }
 
     return ss;
 }
-QString PostWidget::getUsernameHyperlink(const QString& username, const QString& userDesc)
+
+QString PostWidget::getUsernameHyperlink(const Choqok::User &user) const
 {
-    return QLatin1String("<a href='") + d->mCurrentAccount->microblog()->profileUrl(d->mCurrentAccount, username)
-    + QLatin1String("' title=\"") +
-    (userDesc.isEmpty() ? username : userDesc) +
-    QLatin1String("\">") + username + QLatin1String("</a>");
+    return QStringLiteral("<a href=\"%1\" title=\"%2\">%3</a>")
+            .arg(d->mCurrentAccount->microblog()->profileUrl(d->mCurrentAccount, user.userName).toDisplayString())
+            .arg(user.description.isEmpty() ? user.realName : user.description)
+            .arg(user.userName);
 }
 
 void PostWidget::setupUi()
@@ -190,7 +193,7 @@ void PostWidget::setupUi()
     d->buttonsLayout->setSpacing(0);
 
     _mainWidget->setLayout(d->buttonsLayout);
-    connect(_mainWidget, SIGNAL(textChanged()), this, SLOT(setHeight()));
+    connect(_mainWidget, &TextBrowser::textChanged, this, &PostWidget::setHeight);
 
 }
 
@@ -202,12 +205,12 @@ void PostWidget::initUi()
 
     if (isRemoveAvailable()) {
         QPushButton *btnRemove = addButton(QLatin1String("btnRemove"), i18nc("@info:tooltip", "Remove"), QLatin1String("edit-delete"));
-        connect(btnRemove, SIGNAL(clicked(bool)), SLOT(removeCurrentPost()));
+        connect(btnRemove, &QPushButton::clicked, this, &PostWidget::removeCurrentPost);
     }
 
     if (isResendAvailable()) {
         QPushButton *btnResend = addButton(QLatin1String("btnResend"), i18nc("@info:tooltip", "ReSend"), QLatin1String("retweet"));
-        connect(btnResend, SIGNAL(clicked(bool)), SLOT(slotResendPost()));
+        connect(btnResend, &QPushButton::clicked, this, &PostWidget::slotResendPost);
     }
 
     d->mProfileImage = QLatin1String("<img src=\"img://profileImage\" title=\"") + d->mCurrentPost->author.realName + QLatin1String("\" width=\"48\" height=\"48\" />");
@@ -228,16 +231,9 @@ void PostWidget::initUi()
 
 void PostWidget::updateUi()
 {
-    QDateTime time;
-    if (d->mCurrentPost->repeatedDateTime.isNull()) {
-        time = d->mCurrentPost->creationDateTime;
-    } else {
-        time = d->mCurrentPost->repeatedDateTime;
-    }
-
     _mainWidget->setHtml(baseTextTemplate.arg( d->mProfileImage,                     /*1*/
                                                d->mContent,                          /*2*/
-                                               d->mSign.arg(formatDateTime(time)),   /*3*/
+                                               d->mSign,                             /*3*/
                                                d->dir,                               /*4*/
                                                d->mImage,                            /*5*/
                                                d->extraContents                      /*6*/
@@ -489,11 +485,9 @@ QString PostWidget::formatDateTime(const QDateTime &time)
 void PostWidget::removeCurrentPost()
 {
     if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to remove this post from the server?")) == KMessageBox::Yes) {
-        connect(d->mCurrentAccount->microblog(), SIGNAL(postRemoved(Choqok::Account*,Choqok::Post*)),
-                SLOT(slotCurrentPostRemoved(Choqok::Account*,Choqok::Post*)));
-        connect(d->mCurrentAccount->microblog(),
-                SIGNAL(errorPost(Choqok::Account*,Choqok::Post*,Choqok::MicroBlog::ErrorType,QString)),
-                this, SLOT(slotPostError(Choqok::Account*,Choqok::Post*,Choqok::MicroBlog::ErrorType,QString)));
+        connect(d->mCurrentAccount->microblog(), &MicroBlog::postRemoved,
+                this, &PostWidget::slotCurrentPostRemoved);
+        connect(d->mCurrentAccount->microblog(), &MicroBlog::errorPost, this, &PostWidget::slotPostError);
         setReadWithSignal();
         d->mCurrentAccount->microblog()->removePost(d->mCurrentAccount, d->mCurrentPost);
     }
@@ -538,15 +532,15 @@ void PostWidget::fetchImage()
     if (!pix.isNull()) {
         slotImageFetched(d->imageUrl, pix);
     } else {
-        connect(MediaManager::self(), SIGNAL(imageFetched(QString,QPixmap)),
-                this, SLOT(slotImageFetched(QString,QPixmap)));
+        connect(MediaManager::self(), &MediaManager::imageFetched, this,
+                &PostWidget::slotImageFetched);
     }
 }
 
-void PostWidget::slotImageFetched(const QString &remoteUrl, const QPixmap &pixmap)
+void PostWidget::slotImageFetched(const QUrl &remoteUrl, const QPixmap &pixmap)
 {
     if (remoteUrl == d->imageUrl) {
-        disconnect(MediaManager::self(), SIGNAL(imageFetched(QString,QPixmap)), this, SLOT(slotImageFetched(QString,QPixmap)));
+        disconnect(MediaManager::self(), &MediaManager::imageFetched, this, &PostWidget::slotImageFetched);
         d->originalImage = pixmap;
         updatePostImage( width() );
         updateUi();
@@ -560,27 +554,23 @@ void PostWidget::setupAvatar()
     if (!pix.isNull()) {
         avatarFetched(d->mCurrentPost->author.profileImageUrl, pix);
     } else {
-        connect(MediaManager::self(), SIGNAL(imageFetched(QString,QPixmap)),
-                this, SLOT(avatarFetched(QString,QPixmap)));
-        connect(MediaManager::self(), SIGNAL(fetchError(QString,QString)),
-                this, SLOT(avatarFetchError(QString,QString)));
+        connect(MediaManager::self(), &MediaManager::imageFetched, this, &PostWidget::avatarFetched);
+        connect(MediaManager::self(), &MediaManager::fetchError, this, &PostWidget::avatarFetchError);
     }
 }
 
-void PostWidget::avatarFetched(const QString &remoteUrl, const QPixmap &pixmap)
+void PostWidget::avatarFetched(const QUrl &remoteUrl, const QPixmap &pixmap)
 {
     if (remoteUrl == d->mCurrentPost->author.profileImageUrl) {
         const QUrl url(QLatin1String("img://profileImage"));
         _mainWidget->document()->addResource(QTextDocument::ImageResource, url, pixmap);
         updateUi();
-        disconnect(MediaManager::self(), SIGNAL(imageFetched(QString,QPixmap)),
-                   this, SLOT(avatarFetched(QString,QPixmap)));
-        disconnect(MediaManager::self(), SIGNAL(fetchError(QString,QString)),
-                   this, SLOT(avatarFetchError(QString,QString)));
+        disconnect(MediaManager::self(), &MediaManager::imageFetched, this, &PostWidget::avatarFetched);
+        disconnect(MediaManager::self(), &MediaManager::fetchError, this, &PostWidget::avatarFetchError);
     }
 }
 
-void PostWidget::avatarFetchError(const QString &remoteUrl, const QString &errMsg)
+void PostWidget::avatarFetchError(const QUrl &remoteUrl, const QString &errMsg)
 {
     Q_UNUSED(errMsg);
     if (remoteUrl == d->mCurrentPost->author.profileImageUrl) {
@@ -602,11 +592,10 @@ void PostWidget::slotPostError(Account *theAccount, Choqok::Post *post,
 {
     if (theAccount == currentAccount() && post == d->mCurrentPost) {
         qCDebug(CHOQOK) << errorMessage;
-        disconnect(d->mCurrentAccount->microblog(), SIGNAL(postRemoved(Choqok::Account*,Choqok::Post*)),
-                   this, SLOT(slotCurrentPostRemoved(Choqok::Account*,Choqok::Post*)));
-        disconnect(d->mCurrentAccount->microblog(),
-                   SIGNAL(errorPost(Account*,Post*,Choqok::MicroBlog::ErrorType,QString)),
-                   this, SLOT(slotPostError(Account*,Post*,Choqok::MicroBlog::ErrorType,QString)));
+        disconnect(d->mCurrentAccount->microblog(), &MicroBlog::postRemoved,
+                   this, &PostWidget::slotCurrentPostRemoved);
+        disconnect(d->mCurrentAccount->microblog(), &MicroBlog::errorPost,
+                   this, &PostWidget::slotPostError);
     }
 }
 
