@@ -33,11 +33,11 @@ public:
     explicit PumpIOPost();
     virtual ~PumpIOPost();
 
-    QString replies;
+    QUrl replies;
     QStringList shares;
     QStringList to;
     QStringList cc;
     QString replyToObjectType;
 };
 
-#endif //PUMPIOPOST_H
\ No newline at end of file
+#endif //PUMPIOPOST_H
