@@ -65,8 +65,7 @@ void PumpIOPostWidget::checkAnchor(const QUrl &url)
 {
     if (url.scheme() == QLatin1String("thread")) {
         PumpIOShowThread *thread = new PumpIOShowThread(currentAccount(), currentPost());
-        connect(thread, SIGNAL(forwardReply(QString,QString,QString)),
-                this, SIGNAL(reply(QString,QString,QString)));
+        connect(thread, &PumpIOShowThread::forwardReply, this, &PumpIOPostWidget::reply);
         thread->resize(this->width(), thread->height() * 3);
         thread->show();
     } else {
@@ -82,16 +81,17 @@ QString PumpIOPostWidget::generateSign()
     PumpIOAccount *account = qobject_cast<PumpIOAccount * >(currentAccount());
     PumpIOMicroBlog *microblog = qobject_cast<PumpIOMicroBlog * >(account->microblog());
     if (post) {
-        if (post->author.userName != account->username()) {
-            ss += QLatin1String("<b><a href=\"") + microblog->profileUrl(account, post->author.homePageUrl)
-                  + QLatin1String("\" title=\"") + post->author.realName + QLatin1String("\">") +
-                  post->author.userName + QLatin1String("</a></b> - ");
+        ss += QStringLiteral("<b>%1 - </b>").arg(getUsernameHyperlink(currentPost()->author));
+
+        QDateTime time;
+        if (currentPost()->repeatedDateTime.isNull()) {
+            time = currentPost()->creationDateTime;
+        } else {
+            time = currentPost()->repeatedDateTime;
         }
 
-        ss += QLatin1String("<a href=\"") + microblog->postUrl(account, post->author.userName,
-                                                post->postId) + QLatin1String("\" title=\"") +
-              post->creationDateTime.toString(Qt::DefaultLocaleLongDate)
-              + QLatin1String("\">%1</a>");
+        ss += QStringLiteral("<a href=\"%1\" title=\"%2\">%3</a>").arg(currentPost()->link.toDisplayString())
+                .arg(time.toString(Qt::DefaultLocaleLongDate)).arg(formatDateTime(time));
 
         if (!post->source.isEmpty()) {
             ss += QLatin1String(" - ") + post->source;
@@ -111,7 +111,7 @@ QString PumpIOPostWidget::generateSign()
                 } else if (id == QLatin1String("acct:") + account->webfingerID()) {
                     ss += i18n("You") + QLatin1String(", ");
                 } else {
-                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, id)
+                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, post->author.userName).toDisplayString()
                           + QLatin1String("\">") + PumpIOMicroBlog::userNameFromAcct(id) + QLatin1String("</a>, ");
                 }
             }
@@ -134,7 +134,7 @@ QString PumpIOPostWidget::generateSign()
                 } else if (id == QLatin1String("acct:") + account->webfingerID()) {
                     ss += i18n("You") + QLatin1String(", ");
                 } else {
-                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, id)
+                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, post->author.userName).toDisplayString()
                           + QLatin1String("\">") + PumpIOMicroBlog::userNameFromAcct(id) + QLatin1String("</a>, ");
                 }
             }
@@ -152,7 +152,7 @@ QString PumpIOPostWidget::generateSign()
                 if (id == QLatin1String("acct:") + account->webfingerID()) {
                     ss += i18n("You") + QLatin1String(", ");
                 } else {
-                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, id)
+                    ss += QLatin1String("<a href=\"") + microblog->profileUrl(account, post->author.userName).toDisplayString()
                           + QLatin1String("\">") + PumpIOMicroBlog::userNameFromAcct(id) + QLatin1String("</a>, ");
                 }
             }
@@ -170,6 +170,14 @@ QString PumpIOPostWidget::generateSign()
     return ss;
 }
 
+QString PumpIOPostWidget::getUsernameHyperlink(const Choqok::User &user) const
+{
+    return QStringLiteral("<a href=\"%1\" title=\"%2\">%3</a>")
+            .arg(user.homePageUrl.toDisplayString())
+            .arg(user.description.isEmpty() ? user.realName : user.description.toHtmlEscaped())
+            .arg(user.userName);
+}
+
 void PumpIOPostWidget::initUi()
 {
     Choqok::UI::PostWidget::initUi();
@@ -185,13 +193,13 @@ void PumpIOPostWidget::initUi()
         QAction *replyToAct = new QAction(QIcon::fromTheme(QLatin1String("edit-undo")), i18n("Reply to %1",
                                           currentPost()->author.userName), replyMenu);
         replyMenu->addAction(replyToAct);
-        connect(replyToAct, SIGNAL(triggered(bool)), SLOT(slotReplyTo()));
-        connect(d->btnReply, SIGNAL(clicked(bool)), SLOT(slotReplyTo()));
+        connect(replyToAct, &QAction::triggered, this, &PumpIOPostWidget::slotReplyTo);
+        connect(d->btnReply, &QPushButton::clicked, this, &PumpIOPostWidget::slotReplyTo);
     }
 
     d->btnFavorite = addButton(QLatin1String("btnFavorite"), i18nc("@info:tooltip", "Like"), QLatin1String("rating"));
     d->btnFavorite->setCheckable(true);
-    connect(d->btnFavorite, SIGNAL(clicked(bool)), this, SLOT(toggleFavorite()));
+    connect(d->btnFavorite, &QPushButton::clicked, this, &PumpIOPostWidget::toggleFavorite);
     updateFavStat();
 }
 
@@ -200,8 +208,7 @@ void PumpIOPostWidget::toggleFavorite()
     qCDebug(CHOQOK);
     setReadWithSignal();
     PumpIOMicroBlog *microBlog = qobject_cast<PumpIOMicroBlog *>(currentAccount()->microblog());
-    connect(microBlog, SIGNAL(favorite(Choqok::Account*,Choqok::Post*)),
-            this, SLOT(slotToggleFavorite(Choqok::Account*,Choqok::Post*)));
+    connect(microBlog, &PumpIOMicroBlog::favorite, this, &PumpIOPostWidget::slotToggleFavorite);
     microBlog->toggleFavorite(currentAccount(), currentPost());
 }
 
@@ -220,11 +227,10 @@ void PumpIOPostWidget::slotPostError(Choqok::Account *theAccount, Choqok::Post *
     qCDebug(CHOQOK);
     if (theAccount == currentAccount() && post == currentPost()) {
         qCDebug(CHOQOK) << errorMessage;
-        disconnect(currentAccount()->microblog(), SIGNAL(postRemoved(Choqok::Account*,Choqok::Post*)),
-                   this, SLOT(slotCurrentPostRemoved(Choqok::Account*,Choqok::Post*)));
-        disconnect(currentAccount()->microblog(),
-                   SIGNAL(errorPost(Choqok::Account*,Choqok::Post*,Choqok::MicroBlog::ErrorType,QString,Choqok::MicroBlog::ErrorLevel)),
-                   this, SLOT(slotPostError(Choqok::Account*,Choqok::Post*,Choqok::MicroBlog::ErrorType,QString)));
+        disconnect(currentAccount()->microblog(), &Choqok::MicroBlog::postRemoved,
+                   this, &PumpIOPostWidget::slotCurrentPostRemoved);
+        disconnect(currentAccount()->microblog(), &Choqok::MicroBlog::errorPost,
+                   this, &PumpIOPostWidget::slotPostError);
     }
 }
 
@@ -252,7 +258,7 @@ void PumpIOPostWidget::slotReplyTo()
     setReadWithSignal();
     PumpIOPost *post = dynamic_cast<PumpIOPost * >(currentPost());
     if (post->type == QLatin1String("comment")) {
-        Q_EMIT reply(post->replyToPostId, post->replyToUserName, post->replyToObjectType);
+        Q_EMIT reply(post->replyToPostId, post->replyToUser.userName, post->replyToObjectType);
     } else {
         Q_EMIT reply(post->postId, PumpIOMicroBlog::userNameFromAcct(post->author.userId), post->type);
     }
