@@ -28,8 +28,6 @@
 #include <KIO/StoredTransferJob>
 #include <KLocalizedString>
 
-#include <QtOAuth/QtOAuth>
-
 #include "twitterapimicroblog.h"
 
 #include "twitteraccount.h"
@@ -78,25 +76,21 @@ void TwitterSearch::requestSearchResults(const SearchInfo &searchInfo,
     QUrl url = account->apiUrl();
 
     QUrlQuery urlQuery;
-    QOAuth::ParamMap param;
 
     const QString query = searchInfo.query;
     if (searchInfo.option == TwitterSearch::FromUser) {
         url.setPath(url.path() + QLatin1String("/statuses/user_timeline.json"));
 
         urlQuery.addQueryItem(QLatin1String("screen_name"), query);
-        param.insert("screen_name", query.toLatin1());
     } else {
         url.setPath(url.path() + QLatin1String("/search/tweets.json"));
 
         const QByteArray formattedQuery(QUrl::toPercentEncoding(mSearchCode[searchInfo.option] + query));
         urlQuery.addQueryItem(QLatin1String("q"), QString::fromLatin1(formattedQuery));
-        param.insert("q", formattedQuery);
     }
 
     if (!sinceStatusId.isEmpty()) {
         urlQuery.addQueryItem(QLatin1String("since_id"), sinceStatusId);
-        param.insert("since_id", sinceStatusId.toLatin1());
     }
 
     int cntStr;
@@ -105,10 +99,9 @@ void TwitterSearch::requestSearchResults(const SearchInfo &searchInfo,
     } else {
         cntStr = 100;
     }
+    urlQuery.addQueryItem(QLatin1String("tweet_mode"), QLatin1String("extended"));
     urlQuery.addQueryItem(QLatin1String("count"), QString::number(cntStr));
-    param.insert("count", QString::number(cntStr).toLatin1());
 
-    const QUrl tmpUrl(url);
     url.setQuery(urlQuery);
 
     qCDebug(CHOQOK) << url;
@@ -122,10 +115,10 @@ void TwitterSearch::requestSearchResults(const SearchInfo &searchInfo,
 
     job->addMetaData(QStringLiteral("customHTTPHeader"),
                      QStringLiteral("Authorization: ") +
-                     QLatin1String(microblog->authorizationHeader(account, tmpUrl, QOAuth::GET, param)));
+                     QLatin1String(microblog->authorizationHeader(account, url, QNetworkAccessManager::GetOperation)));
 
     mSearchJobs[job] = searchInfo;
-    connect(job, SIGNAL(result(KJob*)), this, SLOT(searchResultsReturned(KJob*)));
+    connect(job, &KIO::StoredTransferJob::result, this, &TwitterSearch::searchResultsReturned);
     job->start();
 }
 
@@ -172,6 +165,12 @@ Choqok::Post *TwitterSearch::readStatusesFromJsonMap(const QVariantMap &var)
     Choqok::Post *post = new Choqok::Post;
 
     post->content = var[QLatin1String("text")].toString();
+
+    // Support for extended tweet_mode
+    if (var.contains(QLatin1String("full_text"))) {
+        post->content = var[QLatin1String("full_text")].toString();
+    }
+
     //%*s %s %d %d:%d:%d %d %d
     post->creationDateTime = dateFromString(var[QLatin1String("created_at")].toString());
     post->postId = var[QLatin1String("id")].toString();
@@ -179,13 +178,13 @@ Choqok::Post *TwitterSearch::readStatusesFromJsonMap(const QVariantMap &var)
     QVariantMap userMap = var[QLatin1String("user")].toMap();
     post->author.realName = userMap[QLatin1String("name")].toString();
     post->author.userName = userMap[QLatin1String("screen_name")].toString();
-    post->author.profileImageUrl = userMap[QLatin1String("profile_image_url")].toString();
+    post->author.profileImageUrl = userMap[QLatin1String("profile_image_url")].toUrl();
     post->isPrivate = false;
     post->isFavorited = false;
     post->replyToPostId = var[QLatin1String("in_reply_to_status_id_str")].toString();
-    post->replyToUserName = var[QLatin1String("in_reply_to_screen_name")].toString();
+    post->replyToUser.userName = var[QLatin1String("in_reply_to_screen_name")].toString();
 
-    post->link = QStringLiteral("https://twitter.com/%1/status/%2").arg(post->author.userName).arg(post->postId);
+    post->link =  QUrl::fromUserInput(QStringLiteral("https://twitter.com/%1/status/%2").arg(post->author.userName).arg(post->postId));
 
     return post;
 }
