@@ -11,7 +11,6 @@ accepted by the membership of KDE e.V. (or its successor approved
 by the membership of KDE e.V.), which shall act as a proxy
 defined in Section 14 of version 3 of the license.
 
-
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -24,15 +23,14 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #ifndef TWITTERTIMELINEWIDGET_H
 #define TWITTERTIMELINEWIDGET_H
 
-#include "twitterapihelper/twitterapitimelinewidget.h"
-
+#include "twitterapitimelinewidget.h"
 
 class TwitterTimelineWidget : public TwitterApiTimelineWidget
 {
 
 public:
-    TwitterTimelineWidget(Choqok::Account* account, const QString& timelineName, QWidget* parent = 0);
-    virtual ~TwitterTimelineWidget();
+    TwitterTimelineWidget(Choqok::Account *account, const QString &timelineName, QWidget *parent = nullptr);
+    ~TwitterTimelineWidget();
 };
 
 #endif // TWITTERTIMELINEWIDGET_H
