@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -25,21 +24,22 @@
 #ifndef NOWLISTENINGCONFIG_H
 #define NOWLISTENINGCONFIG_H
 
-#include <kcmodule.h>
+#include <KCModule>
+
 #include "ui_nowlisteningprefs.h"
 
 class NowListeningConfig : public KCModule
 {
     Q_OBJECT
 public:
-    NowListeningConfig(QWidget* parent, const QVariantList& args);
+    NowListeningConfig(QWidget *parent, const QVariantList &args);
     ~NowListeningConfig();
 
-    virtual void save();
-    virtual void load();
-    virtual void defaults();
+    virtual void save() override;
+    virtual void load() override;
+    virtual void defaults() override;
 
-protected slots:
+protected Q_SLOTS:
     void emitChanged();
 private:
     Ui_NowListeningPrefsBase ui;
