@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -24,11 +23,10 @@
 #ifndef GOO_GL_H
 #define GOO_GL_H
 
-#include <QtCore/QString>
-#include <QtCore/QVariant>
-#include <shortener.h>
+#include <QVariantList>
+
+#include "shortener.h"
 
-class KJob;
 /**
   @author Andrey Esin \<gmlastik@gmail.com\>
 */
@@ -37,9 +35,9 @@ class Goo_gl : public Choqok::Shortener
 {
     Q_OBJECT
 public:
-    Goo_gl( QObject* parent, const QVariantList& args );
+    Goo_gl(QObject *parent, const QVariantList &args);
     ~Goo_gl();
-    QString shorten( const QString& url );
+    virtual QString shorten(const QString &url) override;
 };
 
 #endif //GOO_GL_H
