@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -26,20 +25,20 @@
 #define IS_GD_CONFIG_H
 
 #include <KCModule>
-#include <QWidget>
+
 #include "ui_is_gd_prefs.h"
 
 class Is_gd_Config : public KCModule
 {
     Q_OBJECT
 public:
-    Is_gd_Config(QWidget* parent, const QVariantList&);
+    Is_gd_Config(QWidget *parent, const QVariantList &);
     ~Is_gd_Config();
 
-    virtual void save();
-    virtual void load();
+    virtual void save() override;
+    virtual void load() override;
 
-protected slots:
+protected Q_SLOTS:
     void emitChanged();
 
 private:
