@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -24,22 +23,24 @@
 #ifndef TINYARRO_WS_H
 #define TINYARRO_WS_H
 
+#include <QVariantList>
+
 #include <KCModule>
-#include <QWidget>
+
 #include "ui_tinyarro_ws_prefs.h"
 
 class Tinyarro_ws_Config : public KCModule
 {
     Q_OBJECT
 public:
-    Tinyarro_ws_Config(QWidget* parent, const QVariantList&);
+    Tinyarro_ws_Config(QWidget *parent, const QVariantList &);
     ~Tinyarro_ws_Config();
 
-    virtual void save();
-    virtual void load();
+    virtual void save() override;
+    virtual void load() override;
 protected:
     QMap<QString, QString> hostList;
-protected slots:
+protected Q_SLOTS:
     void emitChanged();
 private:
     Ui_Tinyarro_ws_PrefsBase ui;
