@@ -25,8 +25,10 @@
 #ifndef UNTINY_H
 #define UNTINY_H
 
-#include <plugin.h>
-#include <qqueue.h>
+#include "plugin.h"
+
+#include <QMap>
+#include <QQueue>
 #include <QUrl>
 #include <QPointer>
 
@@ -36,14 +38,11 @@ class Job;
 
 class KJob;
 namespace Choqok {
-    class ShortenManager;
 namespace UI {
     class PostWidget;
 }
 }
 
-class KConfigGroup;
-
 class UnTiny : public Choqok::Plugin
 {
     Q_OBJECT
