@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -25,26 +24,26 @@
 #ifndef MOBYPICTURE_H
 #define MOBYPICTURE_H
 
-#include "plugin.h"
-#include <uploader.h>
+#include "uploader.h"
+
+#include <QMap>
 
 class KJob;
-class KConfigGroup;
 
 class Mobypicture : public Choqok::Uploader
 {
     Q_OBJECT
 public:
-    Mobypicture( QObject* parent, const QList< QVariant >& args );
+    Mobypicture(QObject *parent, const QList< QVariant > &args);
     ~Mobypicture();
 
-    virtual void upload(const KUrl &localUrl, const QByteArray& medium, const QByteArray& mediumType);
+    virtual void upload(const QUrl &localUrl, const QByteArray &medium, const QByteArray &mediumType) override;
 
-protected slots:
-    void slotUpload( KJob *job );
+protected Q_SLOTS:
+    void slotUpload(KJob *job);
 
 private:
-    QMap<KJob*, KUrl> mUrlMap;
+    QMap<KJob *, QUrl> mUrlMap;
 };
 
 #endif // MOBYPICTURE_H
