@@ -26,6 +26,8 @@
 
 #include "uploader.h"
 
+#include <QMap>
+
 class KJob;
 
 class Posterous : public Choqok::Uploader
@@ -35,7 +37,7 @@ public:
     Posterous(QObject *parent, const QList< QVariant > &args);
     ~Posterous();
 
-    virtual void upload(const QUrl &localUrl, const QByteArray &medium, const QByteArray &mediumType);
+    virtual void upload(const QUrl &localUrl, const QByteArray &medium, const QByteArray &mediumType) override;
     QString getAuthToken(const QUrl &localUrl);
 protected Q_SLOTS:
     void slotUpload(KJob *job);
